#include "gs.h"


/** I2C slave address */
#define THIS_ID		(0x18)

#define THIS_SCL_PIN	(6U)
#define THIS_SDA_PIN	(7U)
#define THIS_INT1_PIN	(8U)

/** TWI instance */
#define THIS_INS		(0)


static nrf_drv_twi_t this_twi = NRF_DRV_TWI_INSTANCE(0);
static bool_t this_done;


static void this_listen(nrf_drv_twi_evt_t const* event, void* context);
static int8u_t this_read(int8u_t addr);


void gs_init(void)
{

	int8u_t id;
	
	nrf_drv_twi_config_t const cfg = {
		.scl                = THIS_SCL_PIN,
		.sda                = THIS_SDA_PIN,
		.frequency          = NRF_TWI_FREQ_100K,
		.interrupt_priority = APP_IRQ_PRIORITY_LOWEST,
		.clear_bus_init     = false
    };
	
	nrf_drv_twi_init(&this_twi, &cfg, this_listen, NULL);
	nrf_drv_twi_enable(&this_twi);

	/** Read chip ID */
	id = this_read(0x00);
	NRF_LOG_INFO("ID = %02x", id);

}


static int8u_t this_read(int8u_t addr)
{	
	
	int8u_t data = 0xff;
	
	this_done = FALSE;
	nrf_drv_twi_tx(&this_twi, THIS_ID, &addr, 1, false);
	while(!this_done){
		sd_app_evt_wait();
	}
	
	this_done = FALSE;
	nrf_drv_twi_rx(&this_twi, THIS_ID, &data, 1);
	while(!this_done){
		sd_app_evt_wait();
	}

	return data;
	
}


/** Listens the done event of TWI */
static void this_listen(nrf_drv_twi_evt_t const* event, void* context)
{
	
	switch(event->type){
		
		case NRF_DRV_TWI_EVT_DONE:
			NRF_LOG_INFO("Done");
			this_done = TRUE;
			break;
			
		default:
			break;
			
	}
	
}
